#[non_exhaustive]pub enum ParseError {
Show 19 variants
InvalidMagic,
UnsupportedProtocolVersion,
DocIdMismatch,
BaseVersionUnknown,
UnknownChunk,
LZ4DecoderNeeded,
LZ4DecompressionError,
CompressedDataMissing,
InvalidChunkHeader,
MissingChunk(u32),
InvalidLength,
UnexpectedEOF,
InvalidUTF8,
InvalidRemoteID(VersionConversionError),
InvalidVarInt,
InvalidContent,
GenericInvalidData,
ChecksumFailed,
DataMissing,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidMagic
UnsupportedProtocolVersion
DocIdMismatch
BaseVersionUnknown
UnknownChunk
LZ4DecoderNeeded
LZ4DecompressionError
CompressedDataMissing
InvalidChunkHeader
MissingChunk(u32)
InvalidLength
UnexpectedEOF
InvalidUTF8
InvalidRemoteID(VersionConversionError)
InvalidVarInt
InvalidContent
GenericInvalidData
ChecksumFailed
DataMissing
This error is interesting. We’re loading a chunk but missing some of the data. In the future I’d like to explicitly support this case, and allow the oplog to contain a somewhat- sparse set of data, and load more as needed.