Transaction

Struct Transaction 

pub struct Transaction<'a> { /* private fields */ }
A transaction for batched mutations.

Transactions capture the agent ID so you don’t need to pass it to each mutation. They also provide a clean solution to Rust’s borrow checker issues when working with nested CRDTs.

Transactions are created by Document::transact() and cannot be created directly.

Implementations

Source

impl<'a> Transaction<'a>

pub fn agent(&self) -> AgentId

Get the agent ID for this transaction.

pub fn root(&mut self) -> MapMut<'_>

Get a mutable reference to the root map.

pub fn get_map_mut(&mut self, path: &[&str]) -> Option<MapMut<'_>>

Get a mutable reference to a map at the given path. Returns None if path doesn’t exist.

pub fn get_text_mut(&mut self, path: &[&str]) -> Option<TextMut<'_>>

Get a mutable reference to a text CRDT at the given path. Returns None if path doesn’t exist or isn’t a Text.

pub fn get_set_mut(&mut self, path: &[&str]) -> Option<SetMut<'_>>

Get a mutable reference to a set CRDT at the given path. Returns None if path doesn’t exist or isn’t a Set.

pub fn map_by_id(&mut self, id: CrdtId) -> MapMut<'_>

Get a mutable reference to a map by its CRDT ID.

pub fn text_by_id(&mut self, id: CrdtId) -> Option<TextMut<'_>>

Get a mutable reference to a text CRDT by its ID.

pub fn set_by_id(&mut self, id: CrdtId) -> Option<SetMut<'_>>

Get a mutable reference to a set CRDT by its ID.